@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from PyQt4 import QtCore
 from PyQt4.QtGui import QApplication, QMessageBox
@@ -8,6 +9,6 @@ if __name__ == "__main__":
     app = QApplication(sys.argv)
     ui = MainWindow()
     
-    ui.show()
+    ui.showFullScreen()
     sys.exit(app.exec_())
 #
